@@ -53,6 +53,14 @@ class OVNMechanismDriver(mech_driver.OVNMechanismDriver):
     def ovn_client(self):
         return self._ovn_client
 
+    def _clean_hash_ring(self):
+        """Don't clean the hash ring.
+
+        If this method was not overriden, cleanup would be performed when
+        calling the db sync and running neutron server would lose all the nodes
+        from the ring.
+        """
+
     # Since we are not using the networking_ovn mechanism driver while syncing,
     # we override the post and pre commit methods so that original ones are
     # not called.
@@ -169,7 +177,9 @@ def main():
                       cfg.CONF.ml2.mechanism_drivers)
             return
         cfg.CONF.set_override('mechanism_drivers', ['ovn-sync'], 'ml2')
-        conf.service_plugins = ['networking_ovn.l3.l3_ovn.OVNL3RouterPlugin']
+        conf.service_plugins = [
+            'networking_ovn.l3.l3_ovn.OVNL3RouterPlugin',
+            'neutron.services.segments.plugin.Plugin']
     else:
         LOG.error('Invalid core plugin : ["%s"].', cfg.CONF.core_plugin)
         return
