@@ -18,7 +18,9 @@ import inspect
 import threading
 
 from futurist import periodics
+from neutron.db import segments_db
 from neutron_lib.api.definitions import external_net
+from neutron_lib.api.definitions import segment as segment_def
 from neutron_lib import constants as n_const
 from neutron_lib import context as n_context
 from neutron_lib import exceptions as n_exc
@@ -29,6 +31,7 @@ from ovsdbapp.backend.ovs_idl import event as row_event
 
 from networking_ovn.common import config as ovn_conf
 from networking_ovn.common import constants as ovn_const
+from networking_ovn.common import utils
 from networking_ovn.db import hash_ring as db_hash_ring
 from networking_ovn.db import maintenance as db_maint
 from networking_ovn.db import revision as db_rev
@@ -168,7 +171,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
             },
             ovn_const.TYPE_SECURITY_GROUPS: {
                 'neutron_get': self._ovn_client._plugin.get_security_group,
-                'ovn_get': self._get_security_group,
+                'ovn_get': self._nb_idl.get_port_group,
                 'ovn_create': self._ovn_client.create_security_group,
                 'ovn_delete': self._ovn_client.delete_security_group,
             },
@@ -189,10 +192,6 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
             },
         }
 
-    def _get_security_group(self, uuid):
-        return (self._nb_idl.get_address_set(uuid) or
-                self._nb_idl.get_port_group(uuid))
-
     @property
     def has_lock(self):
         return not self._idl.is_lock_contended
@@ -286,8 +285,7 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         # If Port Groups are not supported or we've already migrated, we don't
         # need to attempt to migrate again.
-        if (not self._nb_idl.is_port_groups_supported() or
-                not self._nb_idl.get_address_sets()):
+        if not self._nb_idl.get_address_sets():
             raise periodics.NeverAgain()
 
         # Only the worker holding a valid lock within OVSDB will perform the
@@ -621,6 +619,44 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
+    # A static spacing value is used here, but this method will only run
+    # once per lock due to the use of periodics.NeverAgain().
+    @periodics.periodic(spacing=600, run_immediately=True)
+    def check_for_localnet_legacy_port_name(self):
+        if not self.has_lock:
+            return
+
+        admin_context = n_context.get_admin_context()
+        cmds = []
+        for ls in self._nb_idl.ls_list().execute(check_error=True):
+            network_id = ls.name.replace('neutron-', '')
+            legacy_name = utils.ovn_provnet_port_name(network_id)
+            legacy_port = None
+            segment_id = None
+            for lsp in ls.ports:
+                if legacy_name == lsp.name:
+                    legacy_port = lsp
+                    break
+            else:
+                continue
+            for segment in segments_db.get_network_segments(
+                    admin_context, network_id):
+                if (segment.get(segment_def.PHYSICAL_NETWORK) ==
+                        legacy_port.options['network_name']):
+                    segment_id = segment['id']
+                    break
+            if not segment_id:
+                continue
+            new_p_name = utils.ovn_provnet_port_name(segment_id)
+            cmds.append(self._nb_idl.db_set('Logical_Switch_Port',
+                                            legacy_port.uuid,
+                                            ('name', new_p_name)))
+        if cmds:
+            with self._nb_idl.transaction(check_error=True) as txn:
+                for cmd in cmds:
+                    txn.add(cmd)
+        raise periodics.NeverAgain()
+
 
 class HashRingHealthCheckPeriodics(object):
 
