@@ -16,6 +16,7 @@ import os
 import re
 
 import netaddr
+from neutron_lib.api.definitions import availability_zone as az_def
 from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import extra_dhcp_opt as edo_ext
 from neutron_lib.api.definitions import l3
@@ -27,6 +28,8 @@ from neutron_lib import context as n_context
 from neutron_lib import exceptions as n_exc
 from neutron_lib.plugins import directory
 from neutron_lib.utils import net as n_utils
+from oslo_config import cfg
+from oslo_log import log
 from oslo_utils import netutils
 from oslo_utils import strutils
 from ovs.db import idl
@@ -37,11 +40,18 @@ from networking_ovn._i18n import _
 from networking_ovn.common import constants
 from networking_ovn.common import exceptions as ovn_exc
 
+LOG = log.getLogger(__name__)
+
+CONF = cfg.CONF
+
 DNS_RESOLVER_FILE = "/etc/resolv.conf"
 
 AddrPairsDiff = collections.namedtuple(
     'AddrPairsDiff', ['added', 'removed', 'changed'])
 
+PortExtraDHCPValidation = collections.namedtuple(
+    'PortExtraDHCPValidation', ['failed', 'invalid_ipv4', 'invalid_ipv6'])
+
 
 def ovn_name(id):
     # The name of the OVN entry will be neutron-<UUID>
@@ -108,6 +118,39 @@ def is_network_device_port(port):
         const.DEVICE_OWNER_PREFIXES)
 
 
+def _is_dhcp_disabled(dhcp_opt):
+    return (dhcp_opt['opt_name'] == constants.DHCP_DISABLED_OPT and
+            dhcp_opt.get('opt_value', '').lower() == 'true')
+
+
+def validate_port_extra_dhcp_opts(port):
+    """Validate port's extra DHCP options.
+
+    :param port: A neutron port.
+    :returns: A PortExtraDHCPValidation object.
+    """
+    invalid = {const.IP_VERSION_4: [], const.IP_VERSION_6: []}
+    failed = False
+    for edo in port.get(edo_ext.EXTRADHCPOPTS, []):
+        ip_version = edo['ip_version']
+        opt_name = edo['opt_name']
+
+        # If DHCP is disabled for this port via this special option,
+        # always succeed the validation
+        if _is_dhcp_disabled(edo):
+            failed = False
+            break
+
+        if opt_name not in constants.SUPPORTED_DHCP_OPTS_MAPPING[ip_version]:
+            invalid[ip_version].append(opt_name)
+            failed = True
+
+    return PortExtraDHCPValidation(
+        failed=failed,
+        invalid_ipv4=invalid[const.IP_VERSION_4] if failed else [],
+        invalid_ipv6=invalid[const.IP_VERSION_6] if failed else [])
+
+
 def get_lsp_dhcp_opts(port, ip_version):
     # Get dhcp options from Neutron port, for setting DHCP_Options row
     # in OVN.
@@ -116,12 +159,12 @@ def get_lsp_dhcp_opts(port, ip_version):
     if is_network_device_port(port):
         lsp_dhcp_disabled = True
     else:
+        mapping = constants.SUPPORTED_DHCP_OPTS_MAPPING[ip_version]
         for edo in port.get(edo_ext.EXTRADHCPOPTS, []):
             if edo['ip_version'] != ip_version:
                 continue
 
-            if edo['opt_name'] == 'dhcp_disabled' and (
-                    edo['opt_value'] in ['True', 'true']):
+            if _is_dhcp_disabled(edo):
                 # OVN native DHCP is disabled on this port
                 lsp_dhcp_disabled = True
                 # Make sure return value behavior not depends on the order and
@@ -129,11 +172,13 @@ def get_lsp_dhcp_opts(port, ip_version):
                 lsp_dhcp_opts.clear()
                 break
 
-            if edo['opt_name'] not in (
-                    constants.SUPPORTED_DHCP_OPTS[ip_version]):
+            if edo['opt_name'] not in mapping:
+                LOG.warning('The DHCP option %(opt_name)s on port %(port)s '
+                            'is not suppported by OVN, ignoring it',
+                            {'opt_name': edo['opt_name'], 'port': port['id']})
                 continue
 
-            opt = edo['opt_name'].replace('-', '_')
+            opt = mapping[edo['opt_name']]
             lsp_dhcp_opts[opt] = edo['opt_value']
 
     return (lsp_dhcp_disabled, lsp_dhcp_opts)
@@ -447,11 +492,15 @@ def is_neutron_dhcp_agent_port(port):
              port['device_id'].startswith('dhcp')))
 
 
+def get_ovn_cms_options(chassis):
+    """Return the list of CMS options in a Chassis."""
+    return [opt.strip() for opt in chassis.external_ids.get(
+            constants.OVN_CMS_OPTIONS, '').split(',')]
+
+
 def is_gateway_chassis(chassis):
     """Check if the given chassis is a gateway chassis"""
-    external_ids = getattr(chassis, 'external_ids', {})
-    return ('enable-chassis-as-gw' in external_ids.get(
-        'ovn-cms-options', '').split(','))
+    return constants.CMS_OPT_CHASSIS_AS_GW in get_ovn_cms_options(chassis)
 
 
 def get_port_capabilities(port):
@@ -471,3 +520,24 @@ def get_port_id_from_gwc_row(row):
     :returns: String containing router port_id.
     """
     return constants.RE_PORT_FROM_GWC.search(row.name).group(2)
+
+
+def get_az_hints(resource):
+    """Return the availability zone hints from a given resource."""
+    return (resource.get(az_def.AZ_HINTS) or CONF.default_availability_zones)
+
+
+def get_chassis_availability_zones(chassis):
+    """Return a list of availability zones from a given OVN Chassis."""
+    azs = []
+    if not chassis:
+        return azs
+
+    opt_key = constants.CMS_OPT_AVAILABILITY_ZONES + '='
+    for opt in get_ovn_cms_options(chassis):
+        if not opt.startswith(opt_key):
+            continue
+        values = opt.split('=')[1]
+        azs = [az.strip() for az in values.split(':') if az.strip()]
+        break
+    return azs
