@@ -26,6 +26,7 @@ from neutron.db import provisioning_blocks
 from neutron.plugins.ml2 import db as ml2_db
 from neutron.services.segments import db as segment_service_db
 from neutron_lib.api.definitions import portbindings
+from neutron_lib.api.definitions import segment as segment_def
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
@@ -174,6 +175,12 @@ class OVNMechanismDriver(api.MechanismDriver):
         registry.subscribe(self._add_segment_host_mapping_for_segment,
                            resources.SEGMENT,
                            events.AFTER_CREATE)
+        registry.subscribe(self.create_segment_provnet_port,
+                           resources.SEGMENT,
+                           events.AFTER_CREATE)
+        registry.subscribe(self.delete_segment_provnet_port,
+                           resources.SEGMENT,
+                           events.AFTER_DELETE)
 
         # Handle security group/rule notifications
         if self.sg_enabled:
@@ -231,6 +238,10 @@ class OVNMechanismDriver(api.MechanismDriver):
         self.patch_plugin_choose("update_agent", update_agent)
         self.patch_plugin_choose("delete_agent", delete_agent)
 
+        # Override availability zone methods
+        self.patch_plugin_merge("get_availability_zones",
+                                get_availability_zones)
+
         # Now IDL connections can be safely used.
         self._post_fork_event.set()
 
@@ -323,6 +334,20 @@ class OVNMechanismDriver(api.MechanismDriver):
                 msg = _('Network type %s is not supported') % network_type
                 raise n_exc.InvalidInput(error_message=msg)
 
+    def create_segment_provnet_port(self, resource, event, trigger,
+                                    context, segment, payload=None):
+        if not segment.get(segment_def.PHYSICAL_NETWORK):
+            return
+        self._ovn_client.create_provnet_port(segment['network_id'], segment)
+
+    def delete_segment_provnet_port(self, resource, event, trigger,
+                                    payload):
+        # NOTE(mjozefcz): Get the last state of segment resource.
+        segment = payload.states[-1]
+        if segment.get(segment_def.PHYSICAL_NETWORK):
+            self._ovn_client.delete_provnet_port(
+                segment['network_id'], segment)
+
     def create_network_precommit(self, context):
         """Allocate resources for a new network.
 
@@ -424,6 +449,17 @@ class OVNMechanismDriver(api.MechanismDriver):
     def delete_subnet_postcommit(self, context):
         self._ovn_client.delete_subnet(context.current['id'])
 
+    def _validate_port_extra_dhcp_opts(self, port):
+        result = utils.validate_port_extra_dhcp_opts(port)
+        if not result.failed:
+            return
+        ipv4_opts = ', '.join(result.invalid_ipv4)
+        ipv6_opts = ', '.join(result.invalid_ipv6)
+        LOG.info('The following extra DHCP options for port %(port_id)s '
+                 'are not supported by OVN. IPv4: "%(ipv4_opts)s" and '
+                 'IPv6: "%(ipv6_opts)s"', {'port_id': port['id'],
+                 'ipv4_opts': ipv4_opts, 'ipv6_opts': ipv6_opts})
+
     def create_port_precommit(self, context):
         """Allocate resources for a new port.
 
@@ -438,6 +474,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         if utils.is_lsp_ignored(port):
             return
         utils.validate_and_get_data_from_binding_profile(port)
+        self._validate_port_extra_dhcp_opts(port)
         if self._is_port_provisioning_required(port, context.host):
             self._insert_port_provisioning_block(context._plugin_context,
                                                  port['id'])
@@ -552,6 +589,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         original_port = context.original
         self._validate_ignored_port(port, original_port)
         utils.validate_and_get_data_from_binding_profile(port)
+        self._validate_port_extra_dhcp_opts(port)
         if self._is_port_provisioning_required(port, context.host,
                                                context.original_host):
             self._insert_port_provisioning_block(context._plugin_context,
@@ -959,7 +997,7 @@ class OVNMechanismDriver(api.MechanismDriver):
                             " networking-ovn-metadata-agent status/logs.",
                             port_id)
 
-    def agent_alive(self, chassis, type_):
+    def agent_alive(self, chassis, type_, update_db):
         nb_cfg = chassis.nb_cfg
         key = ovn_const.OVN_LIVENESS_CHECK_EXT_ID_KEY
         if type_ == ovn_const.OVN_METADATA_AGENT:
@@ -971,15 +1009,17 @@ class OVNMechanismDriver(api.MechanismDriver):
             updated_at = timeutils.parse_isotime(chassis.external_ids[key])
         except KeyError:
             updated_at = timeutils.utcnow(with_timezone=True)
+            update_db = True
 
         # Allow a maximum of 1 difference between expected and read values
         # to avoid false positives.
         if self._nb_ovn.nb_global.nb_cfg - nb_cfg <= 1:
-            # update the time of our successful check
-            value = timeutils.utcnow(with_timezone=True).isoformat()
-            self._sb_ovn.db_set('Chassis', chassis.uuid,
-                                ('external_ids', {key: value})).execute(
-                check_error=True)
+            if update_db:
+                # update the time of our successful check
+                value = timeutils.utcnow(with_timezone=True).isoformat()
+                self._sb_ovn.db_set('Chassis', chassis.uuid,
+                                    ('external_ids', {key: value})).execute(
+                    check_error=True)
             return True
         now = timeutils.utcnow(with_timezone=True)
 
@@ -994,7 +1034,8 @@ class OVNMechanismDriver(api.MechanismDriver):
             'binary': binary,
             'host': chassis.hostname,
             'heartbeat_timestamp': timeutils.utcnow(),
-            'availability_zone': 'n/a',
+            'availability_zone': ', '.join(
+                utils.get_chassis_availability_zones(chassis)),
             'topic': 'n/a',
             'description': description,
             'configurations': {
@@ -1007,7 +1048,7 @@ class OVNMechanismDriver(api.MechanismDriver):
             'alive': alive,
             'admin_state_up': True}
 
-    def agents_from_chassis(self, chassis):
+    def agents_from_chassis(self, chassis, update_db=True):
         agent_dict = {}
 
         # Check for ovn-controller / ovn-controller gateway
@@ -1018,7 +1059,7 @@ class OVNMechanismDriver(api.MechanismDriver):
                 chassis.external_ids.get('ovn-cms-options', [])):
             agent_type = ovn_const.OVN_CONTROLLER_GW_AGENT
 
-        alive = self.agent_alive(chassis, agent_type)
+        alive = self.agent_alive(chassis, agent_type, update_db)
         description = chassis.external_ids.get(
             ovn_const.OVN_AGENT_DESC_KEY, '')
         agent_dict[agent_id] = self._format_agent_info(
@@ -1030,7 +1071,7 @@ class OVNMechanismDriver(api.MechanismDriver):
             ovn_const.OVN_AGENT_METADATA_ID_KEY)
         if metadata_agent_id:
             agent_type = ovn_const.OVN_METADATA_AGENT
-            alive = self.agent_alive(chassis, agent_type)
+            alive = self.agent_alive(chassis, agent_type, update_db)
             description = chassis.external_ids.get(
                 ovn_const.OVN_AGENT_METADATA_DESC_KEY, '')
             agent_dict[metadata_agent_id] = self._format_agent_info(
@@ -1064,7 +1105,11 @@ class OVNMechanismDriver(api.MechanismDriver):
         setattr(self._plugin, method_name, types.MethodType(fn, self._plugin))
 
     def ping_chassis(self):
-        """Update NB_Global.nb_cfg so that Chassis.nb_cfg will increment"""
+        """Update NB_Global.nb_cfg so that Chassis.nb_cfg will increment
+
+        :returns: (bool) True if nb_cfg was updated. False if it was updated
+            recently and this call didn't trigger any update.
+        """
         last_ping = self._nb_ovn.nb_global.external_ids.get(
             ovn_const.OVN_LIVENESS_CHECK_EXT_ID_KEY)
         if last_ping:
@@ -1072,11 +1117,33 @@ class OVNMechanismDriver(api.MechanismDriver):
             next_ping = (timeutils.parse_isotime(last_ping) +
                          datetime.timedelta(seconds=interval))
             if timeutils.utcnow(with_timezone=True) < next_ping:
-                return
+                return False
 
         with self._nb_ovn.create_transaction(check_error=True,
                                              bump_nb_cfg=True) as txn:
             txn.add(self._nb_ovn.check_liveness())
+        return True
+
+    def list_availability_zones(self, context, filters=None):
+        """List all availability zones from gateway chassis."""
+        azs = {}
+        # TODO(lucasagomes): In the future, once the agents API in OVN
+        # gets more stable we should consider getting the information from
+        # the availability zones from the agents API itself. That would
+        # allow us to do things like: Do not schedule router ports on
+        # chassis that are offline (via the "alive" attribute for agents).
+        for ch in self._sb_ovn.chassis_list().execute(check_error=True):
+            # Only take in consideration gateway chassis because that's where
+            # the router ports are scheduled on
+            if not utils.is_gateway_chassis(ch):
+                continue
+
+            azones = utils.get_chassis_availability_zones(ch)
+            for azone in azones:
+                azs[azone] = {'name': azone, 'resource': 'router',
+                              'state': 'available',
+                              'tenant_id': context.project_id}
+        return azs
 
 
 def populate_agents(driver):
@@ -1087,12 +1154,12 @@ def populate_agents(driver):
 
 
 def get_agents(self, context, filters=None, fields=None, _driver=None):
-    _driver.ping_chassis()
+    update_db = _driver.ping_chassis()
     filters = filters or {}
     agent_list = []
     populate_agents(_driver)
     for ch in AGENTS.values():
-        for agent in _driver.agents_from_chassis(ch).values():
+        for agent in _driver.agents_from_chassis(ch, update_db).values():
             if all(agent[k] in v for k, v in filters.items()):
                 agent_list.append(agent)
     return agent_list
@@ -1142,3 +1209,9 @@ def delete_agent(self, context, id, _driver=None):
     get_agent(self, None, id, _driver=_driver)
     raise n_exc.BadRequest(resource='agent',
                            msg='OVN agents cannot be deleted')
+
+
+def get_availability_zones(cls, context, _driver, filters=None, fields=None,
+                           sorts=None, limit=None, marker=None,
+                           page_reverse=False):
+    return list(_driver.list_availability_zones(context, filters).values())
