@@ -521,12 +521,17 @@ class OvnProviderHelper(object):
         raise idlutils.RowNotFound(table='Load_Balancer',
                                    col='name', match=lb_id)
 
-    def _get_or_create_ovn_lb(self, lb_id, protocol, admin_state_up):
+    def _get_or_create_ovn_lb(
+            self, lb_id, protocol, admin_state_up,
+            lb_algorithm=constants.LB_ALGORITHM_SOURCE_IP_PORT):
         """Find or create ovn lb with given protocol
 
            Find the loadbalancer configured with given protocol or
            create required if not found
         """
+        # TODO(mjozefcz): For now we support only one LB algorithm.
+        # As we may extend that in the future we would need to
+        # look here also for lb_algorithm, along with protocol.
         # Make sure that its lowercase - OVN NBDB stores lowercases
         # for this field.
         protocol = protocol.lower()
@@ -553,6 +558,7 @@ class OvnProviderHelper(object):
             lb_info = {
                 'id': lb_id,
                 'protocol': protocol,
+                constants.LB_ALGORITHM: lb_algorithm,
                 'vip_address': ovn_lbs[0].external_ids.get(
                     ovn_const.LB_EXT_IDS_VIP_KEY),
                 'vip_port_id':
@@ -898,6 +904,14 @@ class OvnProviderHelper(object):
                 return True
         return False
 
+    def _are_selection_fields_supported(self):
+        return self.ovn_nbdb_api.is_col_present(
+            'Load_Balancer', 'selection_fields')
+
+    @staticmethod
+    def _get_selection_keys(lb_algorithm):
+        return ovn_const.LB_SELECTION_FIELDS_MAP[lb_algorithm]
+
     def check_lb_protocol(self, lb_id, listener_protocol):
         ovn_lb = self._find_ovn_lbs(lb_id, protocol=listener_protocol)
         if not ovn_lb:
@@ -941,12 +955,18 @@ class OvnProviderHelper(object):
         lr_ref = loadbalancer.get(ovn_const.LB_EXT_IDS_LR_REF_KEY)
         if lr_ref:
             external_ids[ovn_const.LB_EXT_IDS_LR_REF_KEY] = lr_ref
-
+        # In case we have LB algoritm set
+        lb_algorithm = loadbalancer.get(constants.LB_ALGORITHM)
+        kwargs = {
+            'name': loadbalancer[constants.ID],
+            'protocol': protocol,
+            'external_ids': external_ids}
+        if self._are_selection_fields_supported():
+            kwargs['selection_fields'] = self._get_selection_keys(lb_algorithm)
         try:
             self.ovn_nbdb_api.db_create(
-                'Load_Balancer', name=loadbalancer['id'],
-                protocol=protocol,
-                external_ids=external_ids
+                'Load_Balancer',
+                **kwargs
                 ).execute(check_error=True)
             ovn_lb = self._find_ovn_lbs(
                 loadbalancer['id'],
@@ -1358,7 +1378,8 @@ class OvnProviderHelper(object):
         ovn_lb = self._get_or_create_ovn_lb(
             pool['loadbalancer_id'],
             pool['protocol'],
-            pool['admin_state_up'])
+            pool['admin_state_up'],
+            lb_algorithm=pool[constants.LB_ALGORITHM])
         external_ids = copy.deepcopy(ovn_lb.external_ids)
         pool_key = self._get_pool_key(pool['id'],
                                       is_enabled=pool['admin_state_up'])
@@ -1531,9 +1552,9 @@ class OvnProviderHelper(object):
             pool_listeners = self._get_pool_listeners(ovn_lb,
                                                       pool_key)
             listener_status = []
-            for l in pool_listeners:
+            for listener in pool_listeners:
                 listener_status.append(
-                    {'id': l,
+                    {'id': listener,
                      'provisioning_status': constants.ACTIVE})
             status['listeners'] = listener_status
         except Exception:
@@ -1597,9 +1618,9 @@ class OvnProviderHelper(object):
                                    "provisioning_status": constants.ACTIVE}]}
             pool_listeners = self._get_pool_listeners(ovn_lb, pool_key)
             listener_status = []
-            for l in pool_listeners:
+            for listener in pool_listeners:
                 listener_status.append(
-                    {'id': l,
+                    {'id': listener,
                      'provisioning_status': constants.ACTIVE})
             status['listeners'] = listener_status
         except Exception:
@@ -1668,9 +1689,9 @@ class OvnProviderHelper(object):
                                    "provisioning_status": constants.ACTIVE}]}
             pool_listeners = self._get_pool_listeners(ovn_lb, pool_key)
             listener_status = []
-            for l in pool_listeners:
+            for listener in pool_listeners:
                 listener_status.append(
-                    {'id': l,
+                    {'id': listener,
                      'provisioning_status': constants.ACTIVE})
             status['listeners'] = listener_status
         except Exception:
@@ -1727,9 +1748,9 @@ class OvnProviderHelper(object):
 
             pool_listeners = self._get_pool_listeners(ovn_lb, pool_key)
             listener_status = []
-            for l in pool_listeners:
+            for listener in pool_listeners:
                 listener_status.append(
-                    {'id': l,
+                    {'id': listener,
                      'provisioning_status': constants.ACTIVE})
             status['listeners'] = listener_status
         except Exception:
@@ -1782,7 +1803,7 @@ class OvnProviderHelper(object):
         network_driver = get_network_driver()
         try:
             return network_driver.neutron_client.create_port(port)
-        except n_exc.IpAddressAlreadyAllocatedClient:
+        except n_exc.IpAddressAlreadyAllocatedClient as e:
             # Sometimes the VIP is already created (race-conditions)
             # Lets get the it from Neutron API.
             ports = network_driver.neutron_client.list_ports(
@@ -1791,12 +1812,7 @@ class OvnProviderHelper(object):
             if not ports['ports']:
                 LOG.error('Cannot create/get LoadBalancer VIP port with '
                           'fixed IP: %s', vip_d['vip_address'])
-                status = {'loadbalancers': [{
-                    "id": lb_id,
-                    "provisioning_status": constants.ERROR,
-                    "operating_status": constants.ERROR}]}
-                self._update_status_to_octavia(status)
-                return
+                raise e
             # there should only be one port returned
             port = ports['ports'][0]
             LOG.debug('VIP Port already exists, uuid: %s', port['id'])
@@ -1989,6 +2005,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         request_info = {'id': pool.pool_id,
                         'loadbalancer_id': pool.loadbalancer_id,
                         'protocol': pool.protocol,
+                        'lb_algorithm': pool.lb_algorithm,
                         'listener_id': pool.listener_id,
                         'admin_state_up': admin_state_up}
         request = {'type': REQ_TYPE_POOL_CREATE,
@@ -2158,23 +2175,9 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                    'info': request_info}
         self._ovn_helper.add_request(request)
 
-    def member_batch_update(self, members):
-        # Note(rbanerje): all members belong to the same pool.
+    def member_batch_update(self, pool_id, members):
         request_list = []
         skipped_members = []
-        pool_id = None
-        try:
-            pool_id = members[0].pool_id
-        except IndexError:
-            msg = (_('No member information has been passed'))
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
-        except AttributeError:
-            msg = (_('Member does not have proper pool information'))
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
         pool_key, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(pool_id)
         external_ids = copy.deepcopy(ovn_lb.external_ids)
         existing_members = external_ids[pool_key].split(',')
@@ -2252,5 +2255,10 @@ class OvnProviderDriver(driver_base.ProviderDriver):
             vip_dict['vip_port_id'] = port['id']
             vip_dict['vip_address'] = port['fixed_ips'][0]['ip_address']
         except Exception as e:
-            raise driver_exceptions.DriverError(e)
+            kwargs = {}
+            if hasattr(e, 'message'):
+                kwargs = {'user_fault_string': e.message,
+                          'operator_fault_string': e.message}
+            raise driver_exceptions.DriverError(
+                **kwargs)
         return vip_dict
