@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-
 from neutron.services.segments import db as segments_db
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.extensions import test_extraroute
@@ -23,7 +21,6 @@ from neutron_lib.api.definitions import l3
 from neutron_lib.api.definitions import port_security as ps
 from neutron_lib import constants
 from neutron_lib import context
-from neutron_lib.plugins import directory
 from oslo_utils import uuidutils
 from ovsdbapp.backend.ovs_idl import idlutils
 
@@ -61,9 +58,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         self.delete_lrouter_routes = []
         self.delete_lrouter_nats = []
         self.delete_acls = []
-        self.create_address_sets = []
-        self.delete_address_sets = []
-        self.update_address_sets = []
         self.create_port_groups = []
         self.delete_port_groups = []
         self.expected_dhcp_options_rows = []
@@ -378,9 +372,13 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                                           uuidutils.generate_uuid(),
                                           'neutron-' + n1['network']['id']))
         self.delete_lswitches.append('neutron-' + n2['network']['id'])
-        self.delete_lswitch_ports.append(
-            (utils.ovn_provnet_port_name(e1['network']['id']),
-             utils.ovn_name(e1['network']['id'])))
+        for seg in self.segments_plugin.get_segments(
+            self.context,
+                filters={'network_id': [e1['network']['id']]}):
+            if seg.get('physical_network'):
+                self.delete_lswitch_ports.append(
+                    (utils.ovn_provnet_port_name(seg['id']),
+                     utils.ovn_name(e1['network']['id'])))
 
         r1 = self.l3_plugin.create_router(
             self.context,
@@ -578,17 +576,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                                           'neutron-' + r1['id']))
         self.delete_lrouters.append('neutron-' + r2['id'])
 
-        address_set_name = n1_prtr['port']['security_groups'][0]
-        self.create_address_sets.extend([('fake_sg', 'ip4'),
-                                         ('fake_sg', 'ip6')])
-        self.delete_address_sets.append((address_set_name, 'ip6'))
-        address_adds = ['10.0.0.101', '10.0.0.102']
-        address_dels = []
-        for address in n1_prtr['port']['fixed_ips']:
-            address_dels.append(address['ip_address'])
-        self.update_address_sets.append((address_set_name, 'ip4',
-                                         address_adds, address_dels))
-
         self.create_port_groups.extend([{'name': 'pg1', 'acls': []},
                                         {'name': 'pg2', 'acls': []}])
         self.delete_port_groups.append(
@@ -759,26 +746,10 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                 txn.add(self.nb_api.delete_acl(lswitch_name,
                                                lport_name, True))
 
-            for name, ip_version in self.create_address_sets:
-                ovn_name = utils.ovn_addrset_name(name, ip_version)
-                external_ids = {ovn_const.OVN_SG_EXT_ID_KEY: name}
-                txn.add(self.nb_api.create_address_set(
-                    ovn_name, True, external_ids=external_ids))
-
-            for name, ip_version in self.delete_address_sets:
-                ovn_name = utils.ovn_addrset_name(name, ip_version)
-                txn.add(self.nb_api.delete_address_set(ovn_name, True))
-
-            for name, ip_version, ip_adds, ip_dels in self.update_address_sets:
-                ovn_name = utils.ovn_addrset_name(name, ip_version)
-                txn.add(self.nb_api.update_address_set(ovn_name,
-                                                       ip_adds, ip_dels, True))
-
-            if self.nb_api.is_port_groups_supported():
-                for pg in self.create_port_groups:
-                    txn.add(self.nb_api.pg_add(**pg))
-                for pg in self.delete_port_groups:
-                    txn.add(self.nb_api.pg_del(pg))
+            for pg in self.create_port_groups:
+                txn.add(self.nb_api.pg_add(**pg))
+            for pg in self.delete_port_groups:
+                txn.add(self.nb_api.pg_del(pg))
 
             for lport_name in self.reset_lport_dhcpv4_options:
                 txn.add(self.nb_api.set_lswitch_port(lport_name, True,
@@ -849,9 +820,14 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
     def _validate_networks(self, should_match=True):
         db_networks = self._list('networks')
         db_net_ids = [net['id'] for net in db_networks['networks']]
-        db_provnet_ports = [utils.ovn_provnet_port_name(net['id'])
-                            for net in db_networks['networks']
-                            if net.get('provider:physical_network')]
+        db_provnet_ports = []
+        for net in db_networks['networks']:
+            for seg in self.segments_plugin.get_segments(
+                self.context,
+                    filters={'network_id': [net['id']]}):
+                if seg.get('physical_network'):
+                    db_provnet_ports.append(
+                        utils.ovn_provnet_port_name(seg['id']))
 
         # Get the list of lswitch ids stored in the OVN plugin IDL
         _plugin_nb_ovn = self.mech_driver._nb_ovn
@@ -1081,54 +1057,39 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
     def _validate_acls(self, should_match=True):
         # Get the neutron DB ACLs.
         db_acls = []
-        sg_cache = {}
-        subnet_cache = {}
 
         _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if not _plugin_nb_ovn.is_port_groups_supported():
-            for db_port in self._list('ports')['ports']:
-                acls = acl_utils.add_acls(self.plugin,
-                                          context.get_admin_context(),
-                                          db_port,
-                                          sg_cache,
-                                          subnet_cache,
-                                          self.mech_driver._nb_ovn)
-                for acl in acls:
-                    db_acls.append(acl_utils.filter_acl_dict(acl))
-        else:
-            # ACLs due to SGs and default drop port group
-            for sg in self._list('security-groups')['security_groups']:
-                for sgr in sg['security_group_rules']:
-                    acl = acl_utils._add_sg_rule_acl_for_port_group(
-                        utils.ovn_port_group_name(sg['id']), sgr,
-                        self.mech_driver._nb_ovn)
-                    db_acls.append(TestOvnNbSync._build_acl_for_pgs(**acl))
 
-            for acl in acl_utils.add_acls_for_drop_port_group(
-                    ovn_const.OVN_DROP_PORT_GROUP_NAME):
+        # ACLs due to SGs and default drop port group
+        for sg in self._list('security-groups')['security_groups']:
+            for sgr in sg['security_group_rules']:
+                acl = acl_utils._add_sg_rule_acl_for_port_group(
+                    utils.ovn_port_group_name(sg['id']), sgr)
                 db_acls.append(TestOvnNbSync._build_acl_for_pgs(**acl))
 
+        for acl in acl_utils.add_acls_for_drop_port_group(
+                ovn_const.OVN_DROP_PORT_GROUP_NAME):
+            db_acls.append(TestOvnNbSync._build_acl_for_pgs(**acl))
+
         # Get the list of ACLs stored in the OVN plugin IDL.
         plugin_acls = []
         for row in _plugin_nb_ovn._tables['Logical_Switch'].rows.values():
             for acl in getattr(row, 'acls', []):
                 plugin_acls.append(self._build_acl_to_compare(acl))
-        if self.nb_api.is_port_groups_supported():
-            for row in _plugin_nb_ovn._tables['Port_Group'].rows.values():
-                for acl in getattr(row, 'acls', []):
-                    plugin_acls.append(
-                        self._build_acl_to_compare(
-                            acl, extra_fields=['external_ids']))
+        for row in _plugin_nb_ovn._tables['Port_Group'].rows.values():
+            for acl in getattr(row, 'acls', []):
+                plugin_acls.append(
+                    self._build_acl_to_compare(
+                        acl, extra_fields=['external_ids']))
 
         # Get the list of ACLs stored in the OVN monitor IDL.
         monitor_acls = []
         for row in self.nb_api.tables['Logical_Switch'].rows.values():
             for acl in getattr(row, 'acls', []):
                 monitor_acls.append(self._build_acl_to_compare(acl))
-        if _plugin_nb_ovn.is_port_groups_supported():
-            for row in self.nb_api.tables['Port_Group'].rows.values():
-                for acl in getattr(row, 'acls', []):
-                    monitor_acls.append(self._build_acl_to_compare(acl))
+        for row in self.nb_api.tables['Port_Group'].rows.values():
+            for acl in getattr(row, 'acls', []):
+                monitor_acls.append(self._build_acl_to_compare(acl))
 
         if should_match:
             self.assertItemsEqual(db_acls, plugin_acls)
@@ -1350,57 +1311,8 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                     AssertionError, self.assertItemsEqual, r_nats,
                     monitor_nats)
 
-    def _validate_address_sets(self, should_match=True):
-        _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if _plugin_nb_ovn.is_port_groups_supported():
-            # If Port Groups are supported, no Address Sets are expected.
-            # This validation is still useful as we expect existing ones to
-            # be deleted after the sync.
-            db_sgs = []
-        else:
-            db_ports = self._list('ports')['ports']
-            sgs = self._list('security-groups')['security_groups']
-            db_sgs = {}
-            for sg in sgs:
-                for ip_version in ['ip4', 'ip6']:
-                    name = utils.ovn_addrset_name(sg['id'], ip_version)
-                    db_sgs[name] = []
-
-            for port in db_ports:
-                sg_ids = utils.get_lsp_security_groups(port)
-                addresses = acl_utils.acl_port_ips(port)
-                for sg_id in sg_ids:
-                    for ip_version in addresses:
-                        name = utils.ovn_addrset_name(sg_id, ip_version)
-                        db_sgs[name].extend(addresses[ip_version])
-
-        nb_address_sets = _plugin_nb_ovn.get_address_sets()
-        nb_sgs = {}
-        for nb_sgid, nb_values in nb_address_sets.items():
-            nb_sgs[nb_sgid] = nb_values['addresses']
-
-        mn_sgs = {}
-        for row in self.nb_api.tables['Address_Set'].rows.values():
-            mn_sgs[getattr(row, 'name')] = getattr(row, 'addresses')
-
-        if should_match:
-            self.assertItemsEqual(nb_sgs, db_sgs)
-            self.assertItemsEqual(mn_sgs, db_sgs)
-        else:
-            # This condition is to cover the case when we use Port Groups
-            # and we completely deleted the NB DB. At this point, the expected
-            # number of Address Sets is 0 and the observed number in NB is
-            # also 0 so we can't have the asserts below as both will be empty.
-            if _plugin_nb_ovn.is_port_groups_supported() and nb_sgs:
-                self.assertRaises(AssertionError, self.assertItemsEqual,
-                                  nb_sgs, db_sgs)
-                self.assertRaises(AssertionError, self.assertItemsEqual,
-                                  mn_sgs, db_sgs)
-
     def _validate_port_groups(self, should_match=True):
         _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if not _plugin_nb_ovn.is_port_groups_supported():
-            return
 
         db_pgs = []
         for sg in self._list('security-groups')['security_groups']:
@@ -1473,7 +1385,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         self._validate_dhcp_opts(should_match=should_match)
         self._validate_acls(should_match=should_match)
         self._validate_routers_and_router_ports(should_match=should_match)
-        self._validate_address_sets(should_match=should_match)
         self._validate_port_groups(should_match=should_match)
         self._validate_dns_records(should_match=should_match)
 
@@ -1525,17 +1436,11 @@ class TestOvnSbSync(base.TestOVNFunctionalBase):
 
     def setUp(self):
         super(TestOvnSbSync, self).setUp(maintenance_worker=True)
-        self.segments_plugin = directory.get_plugin('segments')
         self.sb_synchronizer = ovn_db_sync.OvnSbSynchronizer(
             self.plugin, self.mech_driver._sb_ovn, self.mech_driver)
         self.addCleanup(self.sb_synchronizer.stop)
         self.ctx = context.get_admin_context()
 
-    def get_additional_service_plugins(self):
-        p = super(TestOvnSbSync, self).get_additional_service_plugins()
-        p.update({'segments': 'neutron.services.segments.plugin.Plugin'})
-        return p
-
     def _sync_resources(self):
         self.sb_synchronizer.sync_hostname_and_physical_networks(self.ctx)
 
@@ -1633,9 +1538,3 @@ class TestOvnNbSyncOverSsl(TestOvnNbSync):
 class TestOvnSbSyncOverSsl(TestOvnSbSync):
     def get_ovsdb_server_protocol(self):
         return 'ssl'
-
-
-@mock.patch('networking_ovn.ovsdb.impl_idl_ovn.OvsdbNbOvnIdl.'
-            'is_port_groups_supported', lambda *args: False)
-class TestOvnNbSyncNoPgs(TestOvnNbSync):
-    pass
