@@ -548,114 +548,15 @@ class TestACLs(base.TestCase):
         ip_version = 'ip4'
         sg_id = sg_rule['security_group_id']
 
-        addrset_name = ovn_utils.ovn_addrset_name(sg_id, ip_version)
+        pg_name = ovn_utils.ovn_pg_addrset_name(sg_id, ip_version)
 
         match = ovn_acl.acl_remote_group_id(sg_rule, ip_version)
         self.assertEqual('', match)
 
         sg_rule['remote_group_id'] = sg_id
         match = ovn_acl.acl_remote_group_id(sg_rule, ip_version)
-        self.assertEqual(' && ip4.src == $' + addrset_name, match)
+        self.assertEqual(' && ip4.src == $' + pg_name, match)
 
         sg_rule['direction'] = 'egress'
         match = ovn_acl.acl_remote_group_id(sg_rule, ip_version)
-        self.assertEqual(' && ip4.dst == $' + addrset_name, match)
-
-    def _test_update_acls_for_security_group(self, use_cache=True):
-        sg = fakes.FakeSecurityGroup.create_one_security_group().info()
-        remote_sg = fakes.FakeSecurityGroup.create_one_security_group().info()
-        sg_rule = fakes.FakeSecurityGroupRule.create_one_security_group_rule({
-            'security_group_id': sg['id'],
-            'remote_group_id': remote_sg['id']
-        }).info()
-        port = fakes.FakePort.create_one_port({
-            'security_groups': [sg['id']]
-        }).info()
-        self.plugin.get_ports.return_value = [port]
-        if use_cache:
-            sg_ports_cache = {sg['id']: [{'port_id': port['id']}],
-                              remote_sg['id']: []}
-        else:
-            sg_ports_cache = None
-            self.plugin._get_port_security_group_bindings.return_value = \
-                [{'port_id': port['id']}]
-
-        # Build ACL for validation.
-        expected_acl = ovn_acl._add_sg_rule_acl_for_port(port, sg_rule)
-        expected_acl.pop('lport')
-        expected_acl.pop('lswitch')
-
-        # Validate ACLs when port has security groups.
-        ovn_acl.update_acls_for_security_group(self.plugin,
-                                               self.admin_context,
-                                               self.driver._nb_ovn,
-                                               sg['id'],
-                                               sg_rule,
-                                               sg_ports_cache=sg_ports_cache)
-        self.driver._nb_ovn.update_acls.assert_called_once_with(
-            [port['network_id']],
-            mock.ANY,
-            {port['id']: expected_acl},
-            need_compare=False,
-            is_add_acl=True
-        )
-
-    def test_update_acls_for_security_group_cache(self):
-        self._test_update_acls_for_security_group(use_cache=True)
-
-    def test_update_acls_for_security_group_no_cache(self):
-        self._test_update_acls_for_security_group(use_cache=False)
-
-    def test_acl_port_ips(self):
-        port4 = fakes.FakePort.create_one_port({
-            'fixed_ips': [{'subnet_id': 'subnet-ipv4',
-                           'ip_address': '10.0.0.1'}],
-        }).info()
-        port46 = fakes.FakePort.create_one_port({
-            'fixed_ips': [{'subnet_id': 'subnet-ipv4',
-                           'ip_address': '10.0.0.2'},
-                          {'subnet_id': 'subnet-ipv6',
-                           'ip_address': 'fde3:d45:df72::1'}],
-        }).info()
-        port6 = fakes.FakePort.create_one_port({
-            'fixed_ips': [{'subnet_id': 'subnet-ipv6',
-                           'ip_address': '2001:db8::8'}],
-        }).info()
-
-        addresses = ovn_acl.acl_port_ips(port4)
-        self.assertEqual({'ip4': [port4['fixed_ips'][0]['ip_address']],
-                          'ip6': []},
-                         addresses)
-
-        addresses = ovn_acl.acl_port_ips(port46)
-        self.assertEqual({'ip4': [port46['fixed_ips'][0]['ip_address']],
-                          'ip6': [port46['fixed_ips'][1]['ip_address']]},
-                         addresses)
-
-        addresses = ovn_acl.acl_port_ips(port6)
-        self.assertEqual({'ip4': [],
-                          'ip6': [port6['fixed_ips'][0]['ip_address']]},
-                         addresses)
-
-    def test_sg_disabled(self):
-        sg = fakes.FakeSecurityGroup.create_one_security_group().info()
-        port = fakes.FakePort.create_one_port({
-            'security_groups': [sg['id']]
-        }).info()
-
-        with mock.patch('networking_ovn.common.acl.is_sg_enabled',
-                        return_value=False):
-            acl_list = ovn_acl.add_acls(self.plugin,
-                                        self.admin_context,
-                                        port, {}, {}, self.driver._ovn)
-            self.assertEqual([], acl_list)
-
-            ovn_acl.update_acls_for_security_group(self.plugin,
-                                                   self.admin_context,
-                                                   self.driver._ovn,
-                                                   sg['id'],
-                                                   None)
-            self.driver._ovn.update_acls.assert_not_called()
-
-            addresses = ovn_acl.acl_port_ips(port)
-            self.assertEqual({'ip4': [], 'ip6': []}, addresses)
+        self.assertEqual(' && ip4.dst == $' + pg_name, match)
