@@ -71,10 +71,6 @@ class FakeOvsdbNbOvnIdl(object):
         self.idl = mock.Mock()
         self.add_static_route = mock.Mock()
         self.delete_static_route = mock.Mock()
-        self.create_address_set = mock.Mock()
-        self.update_address_set_ext_ids = mock.Mock()
-        self.delete_address_set = mock.Mock()
-        self.update_address_set = mock.Mock()
         self.get_all_chassis_gateway_bindings = mock.Mock()
         self.get_chassis_gateways = mock.Mock()
         self.get_gateway_chassis_binding = mock.Mock()
@@ -99,12 +95,14 @@ class FakeOvsdbNbOvnIdl(object):
         self.get_parent_port.return_value = []
         self.dns_add = mock.Mock()
         self.get_lswitch = mock.Mock()
-        fake_ovs_row = FakeOvsdbRow.create_one_ovsdb_row()
-        self.get_lswitch.return_value = fake_ovs_row
+        self.fake_ls_row = FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={'ports': []})
+        fake_lsp_row = FakeOvsdbRow.create_one_ovsdb_row()
+        self.get_lswitch.return_value = self.fake_ls_row
         self.get_lswitch_port = mock.Mock()
-        self.get_lswitch_port.return_value = fake_ovs_row
+        self.get_lswitch_port.return_value = fake_lsp_row
         self.get_ls_and_dns_record = mock.Mock()
-        self.get_ls_and_dns_record.return_value = (fake_ovs_row, None)
+        self.get_ls_and_dns_record.return_value = (self.fake_ls_row, None)
         self.ls_set_dns_records = mock.Mock()
         self.get_floatingip = mock.Mock()
         self.get_floatingip.return_value = None
@@ -121,12 +119,6 @@ class FakeOvsdbNbOvnIdl(object):
         self.get_lrouter.return_value = None
         self.delete_lrouter_ext_gw = mock.Mock()
         self.delete_lrouter_ext_gw.return_value = None
-        self.is_port_groups_supported = mock.Mock()
-        # TODO(lucasagomes): Flip this return value to True at some point,
-        # port groups should be the default method used by networking-ovn
-        self.is_port_groups_supported.return_value = False
-        self.get_address_set = mock.Mock()
-        self.get_address_set.return_value = None
         self.pg_acl_add = mock.Mock()
         self.pg_acl_del = mock.Mock()
         self.pg_del = mock.Mock()
@@ -171,6 +163,8 @@ class FakeOvsdbSbOvnIdl(object):
         self.db_set = mock.Mock()
         self.is_col_present = mock.Mock()
         self.is_col_present.return_value = False
+        self.lookup = mock.MagicMock()
+        self.chassis_list = mock.MagicMock()
 
 
 class FakeOvsdbTransaction(object):
@@ -757,3 +751,33 @@ class FakeOVNRouter(object):
              'enabled': router.get('admin_state_up') or False,
              'name': utils.ovn_name(router['id']),
              'static_routes': routes})
+
+
+class FakeChassis(object):
+
+    @staticmethod
+    def create(attrs=None, az_list=None, chassis_as_gw=False):
+        cms_opts = []
+        if az_list:
+            cms_opts.append("%s=%s" % (ovn_const.CMS_OPT_AVAILABILITY_ZONES,
+                                       ':'.join(az_list)))
+        if chassis_as_gw:
+            cms_opts.append(ovn_const.CMS_OPT_CHASSIS_AS_GW)
+
+        external_ids = {}
+        if cms_opts:
+            external_ids[ovn_const.OVN_CMS_OPTIONS] = ','.join(cms_opts)
+
+        attrs = {
+            'encaps': [],
+            'external_ids': external_ids,
+            'hostname': '',
+            'name': uuidutils.generate_uuid(),
+            'nb_cfg': 0,
+            'other_config': {},
+            'transport_zones': [],
+            'vtep_logical_switches': []}
+
+        # Overwrite default attributes.
+        attrs.update(attrs)
+        return type('Chassis', (object, ), attrs)
