@@ -936,171 +936,6 @@ class TestDelStaticRouteCommand(TestBaseCommand):
             self.assertEqual([mock.ANY], fake_lrouter.static_routes)
 
 
-class TestAddAddrSetCommand(TestBaseCommand):
-
-    def test_addrset_exists(self):
-        with mock.patch.object(idlutils, 'row_by_value',
-                               return_value=mock.ANY):
-            cmd = commands.AddAddrSetCommand(
-                self.ovn_api, 'fake-addrset', may_exist=True)
-            cmd.run_idl(self.transaction)
-            self.transaction.insert.assert_not_called()
-
-    def test_addrset_add_exists(self):
-        fake_addrset = fakes.FakeOvsdbRow.create_one_ovsdb_row()
-        self.ovn_api._tables['Address_Set'].rows[fake_addrset.uuid] = \
-            fake_addrset
-        self.transaction.insert.return_value = fake_addrset
-        cmd = commands.AddAddrSetCommand(
-            self.ovn_api, fake_addrset.name, may_exist=False)
-        cmd.run_idl(self.transaction)
-        # NOTE(rtheis): Mocking the transaction allows this insert
-        # to succeed when it normally would fail due the duplicate name.
-        self.transaction.insert.assert_called_once_with(
-            self.ovn_api._tables['Address_Set'])
-
-    def _test_addrset_add(self, may_exist=True):
-        with mock.patch.object(idlutils, 'row_by_value',
-                               return_value=None):
-            fake_addrset = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-                attrs={'foo': ''})
-            self.transaction.insert.return_value = fake_addrset
-            cmd = commands.AddAddrSetCommand(
-                self.ovn_api, 'fake-addrset', may_exist=may_exist,
-                foo='bar')
-            cmd.run_idl(self.transaction)
-            self.transaction.insert.assert_called_once_with(
-                self.ovn_api._tables['Address_Set'])
-            self.assertEqual('fake-addrset', fake_addrset.name)
-            self.assertEqual('bar', fake_addrset.foo)
-
-    def test_addrset_add_may_exist(self):
-        self._test_addrset_add(may_exist=True)
-
-    def test_addrset_add_ignore_exists(self):
-        self._test_addrset_add(may_exist=False)
-
-
-class TestDelAddrSetCommand(TestBaseCommand):
-
-    def _test_addrset_del_no_exist(self, if_exists=True):
-        with mock.patch.object(idlutils, 'row_by_value',
-                               side_effect=idlutils.RowNotFound):
-            cmd = commands.DelAddrSetCommand(
-                self.ovn_api, 'fake-addrset', if_exists=if_exists)
-            if if_exists:
-                cmd.run_idl(self.transaction)
-            else:
-                self.assertRaises(RuntimeError, cmd.run_idl, self.transaction)
-
-    def test_addrset_no_exist_ignore(self):
-        self._test_addrset_del_no_exist(if_exists=True)
-
-    def test_addrset_no_exist_fail(self):
-        self._test_addrset_del_no_exist(if_exists=False)
-
-    def test_addrset_del(self):
-        fake_addrset = fakes.FakeOvsdbRow.create_one_ovsdb_row()
-        self.ovn_api._tables['Address_Set'].rows[fake_addrset.uuid] = \
-            fake_addrset
-        with mock.patch.object(idlutils, 'row_by_value',
-                               return_value=fake_addrset):
-            cmd = commands.DelAddrSetCommand(
-                self.ovn_api, fake_addrset.name, if_exists=True)
-            cmd.run_idl(self.transaction)
-            fake_addrset.delete.assert_called_once_with()
-
-
-class TestUpdateAddrSetCommand(TestBaseCommand):
-
-    def _test_addrset_update_no_exist(self, if_exists=True):
-        with mock.patch.object(idlutils, 'row_by_value',
-                               side_effect=idlutils.RowNotFound):
-            cmd = commands.UpdateAddrSetCommand(
-                self.ovn_api, 'fake-addrset',
-                addrs_add=[], addrs_remove=[],
-                if_exists=if_exists)
-            if if_exists:
-                cmd.run_idl(self.transaction)
-            else:
-                self.assertRaises(RuntimeError, cmd.run_idl, self.transaction)
-
-    def test_addrset_no_exist_ignore(self):
-        self._test_addrset_update_no_exist(if_exists=True)
-
-    def test_addrset_no_exist_fail(self):
-        self._test_addrset_update_no_exist(if_exists=False)
-
-    def _test_addrset_update(self, addrs_add=None, addrs_del=None):
-        save_address = '10.0.0.1'
-        initial_addresses = [save_address]
-        final_addresses = [save_address]
-        expected_addvalue_calls = []
-        expected_delvalue_calls = []
-        if addrs_add:
-            for addr_add in addrs_add:
-                final_addresses.append(addr_add)
-                expected_addvalue_calls.append(
-                    mock.call('addresses', addr_add))
-        if addrs_del:
-            for addr_del in addrs_del:
-                initial_addresses.append(addr_del)
-                expected_delvalue_calls.append(
-                    mock.call('addresses', addr_del))
-        fake_addrset = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'addresses': initial_addresses})
-        with mock.patch.object(idlutils, 'row_by_value',
-                               return_value=fake_addrset):
-            cmd = commands.UpdateAddrSetCommand(
-                self.ovn_api, fake_addrset.name,
-                addrs_add=addrs_add, addrs_remove=addrs_del,
-                if_exists=True)
-            cmd.run_idl(self.transaction)
-            fake_addrset.addvalue.assert_has_calls(expected_addvalue_calls)
-            fake_addrset.delvalue.assert_has_calls(expected_delvalue_calls)
-
-    def test_addrset_update_add(self):
-        self._test_addrset_update(addrs_add=['10.0.0.4'])
-
-    def test_addrset_update_del(self):
-        self._test_addrset_update(addrs_del=['10.0.0.2'])
-
-
-class TestUpdateAddrSetExtIdsCommand(TestBaseCommand):
-    def setUp(self):
-        super(TestUpdateAddrSetExtIdsCommand, self).setUp()
-        self.ext_ids = {ovn_const.OVN_SG_EXT_ID_KEY: 'default'}
-
-    def _test_addrset_extids_update_no_exist(self, if_exists=True):
-        with mock.patch.object(idlutils, 'row_by_value',
-                               side_effect=idlutils.RowNotFound):
-            cmd = commands.UpdateAddrSetExtIdsCommand(
-                self.ovn_api, 'fake-addrset', self.ext_ids,
-                if_exists=if_exists)
-            if if_exists:
-                cmd.run_idl(self.transaction)
-            else:
-                self.assertRaises(RuntimeError, cmd.run_idl, self.transaction)
-
-    def test_addrset_no_exist_ignore(self):
-        self._test_addrset_extids_update_no_exist(if_exists=True)
-
-    def test_addrset_no_exist_fail(self):
-        self._test_addrset_extids_update_no_exist(if_exists=False)
-
-    def test_addrset_extids_update(self):
-        new_ext_ids = {ovn_const.OVN_SG_EXT_ID_KEY: 'default-new'}
-        fake_addrset = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'external_ids': self.ext_ids})
-        with mock.patch.object(idlutils, 'row_by_value',
-                               return_value=fake_addrset):
-            cmd = commands.UpdateAddrSetExtIdsCommand(
-                self.ovn_api, fake_addrset.name,
-                new_ext_ids, if_exists=True)
-            cmd.run_idl(self.transaction)
-            self.assertEqual(new_ext_ids, fake_addrset.external_ids)
-
-
 class TestUpdateChassisExtIdsCommand(TestBaseCommand):
     def setUp(self):
         super(TestUpdateChassisExtIdsCommand, self).setUp()
