@@ -56,6 +56,23 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                           'mtu': 1450,
                           'provider:physical_network': 'physnet2'}]
 
+        self.segments = [{'id': 'seg1',
+                          'network_id': 'n1',
+                          'physical_network': 'physnet1',
+                          'network_type': 'vlan',
+                          'segmentation_id': 1000},
+                         {'id': 'seg2',
+                          'network_id': 'n2',
+                          'physical_network': None,
+                          'network_type': 'geneve'},
+                         {'id': 'seg4',
+                          'network_id': 'n4',
+                          'physical_network': 'physnet2',
+                          'network_type': 'flat'}]
+        self.segments_map = {
+            k['network_id']: k
+            for k in self.segments}
+
         self.subnets = [{'id': 'n1-s1',
                          'network_id': 'n1',
                          'enable_dhcp': True,
@@ -209,25 +226,6 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
               'match': 'outport == "p2n2" && ip4 && '
               'ip4.src == 10.0.0.0/24 && udp && '
               'udp.src == 67 && udp.dst == 68'}]}
-        self.address_sets_ovn = {
-            'as_ip4_sg1': {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY:
-                                            'all-tcp'},
-                           'name': 'as_ip4_sg1',
-                           'addresses': ['10.0.0.4']},
-            'as_ip4_sg2': {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY:
-                                            'all-tcpe'},
-                           'name': 'as_ip4_sg2',
-                           'addresses': []},
-            'as_ip6_sg2': {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY:
-                                            'all-tcpe'},
-                           'name': 'as_ip6_sg2',
-                           'addresses': ['fd79:e1c:a55::816:eff:eff:ff2',
-                                         'fd79:e1c:a55::816:eff:eff:ff3']},
-            'as_ip4_del': {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY:
-                                            'all-delete'},
-                           'name': 'as_ip4_delete',
-                           'addresses': ['10.0.0.4']},
-            }
 
         self.routers = [{'id': 'r1', 'routes': [{'nexthop': '20.0.0.100',
                          'destination': '11.0.0.0/24'}, {
@@ -320,16 +318,23 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         self.lswitches_with_ports = [{'name': 'neutron-n1',
                                       'ports': ['p1n1', 'p3n1'],
-                                      'provnet_port': None},
+                                      'provnet_ports': []},
                                      {'name': 'neutron-n3',
                                       'ports': ['p1n3', 'p2n3'],
-                                      'provnet_port': None},
+                                      'provnet_ports': []},
                                      {'name': 'neutron-n4',
                                       'ports': [],
-                                      'provnet_port': 'provnet-n4'}]
+                                      'provnet_ports': [
+                                          'provnet-seg4',
+                                          'provnet-orphaned-segment']}]
 
         self.lrport_networks = ['fdad:123:456::1/64', 'fdad:cafe:a1b2::1/64']
 
+    def get_additional_service_plugins(self):
+        p = super(TestOvnNbSyncML2, self).get_additional_service_plugins()
+        p.update({'segments': 'neutron.services.segments.plugin.Plugin'})
+        return p
+
     def _fake_get_ovn_dhcp_options(self, subnet, network, server_mac=None):
         if subnet['id'] == 'n1-s1':
             return {'cidr': '10.0.0.0/24',
@@ -364,11 +369,24 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_api = ovn_nb_synchronizer.ovn_api
         ovn_driver = ovn_nb_synchronizer.ovn_driver
         l3_plugin = ovn_nb_synchronizer.l3_plugin
+        segments_plugin = ovn_nb_synchronizer.segments_plugin
 
         core_plugin.get_networks = mock.Mock()
         core_plugin.get_networks.return_value = self.networks
         core_plugin.get_subnets = mock.Mock()
         core_plugin.get_subnets.return_value = self.subnets
+
+        def get_segments(self, filters):
+            segs = []
+            for segment in self.segments:
+                if segment['network_id'] == filters['network_id'][0]:
+                    segs.append(segment)
+            return segs
+
+        segments_plugin.get_segments = mock.Mock()
+        segments_plugin.get_segments.side_effect = (
+            lambda x, filters: get_segments(self, filters))
+
         # following block is used for acl syncing unit-test
 
         # With the given set of values in the unit testing,
@@ -392,9 +410,6 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_nb_synchronizer.get_acls.return_value = self.acls_ovn
         core_plugin.get_security_groups = mock.MagicMock(
             return_value=self.security_groups)
-        ovn_nb_synchronizer.get_address_sets = mock.Mock()
-        ovn_nb_synchronizer.get_address_sets.return_value =\
-            self.address_sets_ovn
         get_port_groups = mock.MagicMock()
         get_port_groups.execute.return_value = self.port_groups_ovn
         ovn_api.db_list_rows.return_value = get_port_groups
@@ -445,7 +460,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_driver.validate_and_get_data_from_binding_profile = mock.Mock()
         ovn_nb_synchronizer._ovn_client.create_port = mock.Mock()
         ovn_nb_synchronizer._ovn_client.create_port.return_value = mock.ANY
-        ovn_nb_synchronizer._ovn_client._create_provnet_port = mock.Mock()
+        ovn_nb_synchronizer._ovn_client.create_provnet_port = mock.Mock()
         ovn_api.ls_del = mock.Mock()
         ovn_api.delete_lswitch_port = mock.Mock()
 
@@ -505,9 +520,6 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                                    'port_id': 'p1n2'},
                                   'uuid': 'UUID6'}}}
 
-        ovn_api.create_address_set = mock.Mock()
-        ovn_api.delete_address_set = mock.Mock()
-        ovn_api.update_address_set = mock.Mock()
         ovn_nb_synchronizer._ovn_client._add_subnet_dhcp_options = mock.Mock()
         ovn_nb_synchronizer._ovn_client._get_ovn_dhcp_options = mock.Mock()
         ovn_nb_synchronizer._ovn_client._get_ovn_dhcp_options.side_effect = (
@@ -528,54 +540,17 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                  add_static_route_list, del_static_route_list,
                                  add_snat_list, del_snat_list,
                                  add_floating_ip_list, del_floating_ip_list,
-                                 add_address_set_list, del_address_set_list,
-                                 update_address_set_list,
                                  add_subnet_dhcp_options_list,
                                  delete_dhcp_options_list,
                                  add_port_groups_list,
-                                 del_port_groups_list,
-                                 port_groups_supported=False):
+                                 del_port_groups_list):
         self._test_mocks_helper(ovn_nb_synchronizer)
 
-        core_plugin = ovn_nb_synchronizer.core_plugin
         ovn_api = ovn_nb_synchronizer.ovn_api
-        ovn_api.is_port_groups_supported.return_value = port_groups_supported
         mock.patch("networking_ovn.ovsdb.impl_idl_ovn.get_connection").start()
 
         ovn_nb_synchronizer.do_sync()
 
-        if not ovn_api.is_port_groups_supported():
-            get_security_group_calls = [mock.call(mock.ANY, sg['id'])
-                                        for sg in self.security_groups]
-            self.assertEqual(len(self.security_groups),
-                             core_plugin.get_security_group.call_count)
-            core_plugin.get_security_group.assert_has_calls(
-                get_security_group_calls, any_order=True)
-
-        create_address_set_calls = [mock.call(**a)
-                                    for a in add_address_set_list]
-        self.assertEqual(
-            len(add_address_set_list),
-            ovn_api.create_address_set.call_count)
-        ovn_api.create_address_set.assert_has_calls(
-            create_address_set_calls, any_order=True)
-
-        del_address_set_calls = [mock.call(**d)
-                                 for d in del_address_set_list]
-        self.assertEqual(
-            len(del_address_set_list),
-            ovn_api.delete_address_set.call_count)
-        ovn_api.delete_address_set.assert_has_calls(
-            del_address_set_calls, any_order=True)
-
-        update_address_set_calls = [mock.call(**u)
-                                    for u in update_address_set_list]
-        self.assertEqual(
-            len(update_address_set_list),
-            ovn_api.update_address_set.call_count)
-        ovn_api.update_address_set.assert_has_calls(
-            update_address_set_calls, any_order=True)
-
         create_port_groups_calls = [mock.call(**a)
                                     for a in add_port_groups_list]
         self.assertEqual(
@@ -608,14 +583,16 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
             create_port_calls, any_order=True)
 
         create_provnet_port_calls = [
-            mock.call(mock.ANY, mock.ANY,
-                      network['provider:physical_network'],
-                      network['provider:segmentation_id'])
-            for network in create_provnet_port_list]
+            mock.call(
+                network['id'],
+                self.segments_map[network['id']],
+                txn=mock.ANY)
+            for network in create_provnet_port_list
+            if network.get('provider:physical_network')]
         self.assertEqual(
             len(create_provnet_port_list),
-            ovn_nb_synchronizer._ovn_client._create_provnet_port.call_count)
-        ovn_nb_synchronizer._ovn_client._create_provnet_port.assert_has_calls(
+            ovn_nb_synchronizer._ovn_client.create_provnet_port.call_count)
+        ovn_nb_synchronizer._ovn_client.create_provnet_port.assert_has_calls(
             create_provnet_port_calls, any_order=True)
 
         self.assertEqual(len(del_network_list),
@@ -685,9 +662,9 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_nb_synchronizer._ovn_client.create_router.assert_has_calls(
             create_router_calls, any_order=True)
 
-        create_router_port_calls = [mock.call(p['device_id'],
-                                              mock.ANY)
-                                    for p in create_router_port_list]
+        create_router_port_calls = [
+            mock.call(self.routers[i], mock.ANY)
+            for i, p in enumerate(create_router_port_list)]
         self.assertEqual(
             len(create_router_port_list),
             ovn_nb_synchronizer._ovn_client._create_lrouter_port.call_count)
@@ -738,13 +715,15 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_api.delete_dhcp_options.assert_has_calls(
             delete_dhcp_options_calls, any_order=True)
 
-    def _test_ovn_nb_sync_mode_repair_helper(self, port_groups_supported=True):
+    def test_ovn_nb_sync_mode_repair(self):
 
         create_network_list = [{'net': {'id': 'n2', 'mtu': 1450},
                                 'ext_ids': {}}]
         del_network_list = ['neutron-n3']
         del_port_list = [{'id': 'p3n1', 'lswitch': 'neutron-n1'},
-                         {'id': 'p1n1', 'lswitch': 'neutron-n1'}]
+                         {'id': 'p1n1', 'lswitch': 'neutron-n1'},
+                         {'id': 'provnet-orphaned-segment',
+                          'lswitch': 'neutron-n4'}]
         create_port_list = self.ports
         for port in create_port_list:
             if port['id'] in ['p1n1', 'fp1']:
@@ -816,37 +795,11 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         update_router_port_list[0].update(
             {'networks': self.lrport_networks})
 
-        if not port_groups_supported:
-            add_address_set_list = [
-                {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY: 'sg1'},
-                 'name': 'as_ip6_sg1',
-                 'addresses': ['fd79:e1c:a55::816:eff:eff:ff2']}]
-            del_address_set_list = [{'name': 'as_ip4_del'}]
-            update_address_set_list = [
-                {'addrs_remove': [],
-                 'addrs_add': ['10.0.0.4'],
-                 'name': 'as_ip4_sg2'},
-                {'addrs_remove': ['fd79:e1c:a55::816:eff:eff:ff3'],
-                 'addrs_add': [],
-                 'name': 'as_ip6_sg2'}]
-            # If Port Groups are not supported, we don't expect any of those
-            # to be created/deleted.
-            add_port_groups_list = []
-            del_port_groups_list = []
-        else:
-            add_port_groups_list = [
-                {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY: 'sg2'},
-                 'name': 'pg_sg2',
-                 'acls': []}]
-            del_port_groups_list = ['pg_unknown_del']
-            # If using Port Groups, no Address Set shall be created/updated
-            # and all the existing ones have to be removed.
-            add_address_set_list = []
-            update_address_set_list = []
-            del_address_set_list = [{'name': 'as_ip4_sg1'},
-                                    {'name': 'as_ip4_sg2'},
-                                    {'name': 'as_ip6_sg2'},
-                                    {'name': 'as_ip4_del'}]
+        add_port_groups_list = [
+            {'external_ids': {ovn_const.OVN_SG_EXT_ID_KEY: 'sg2'},
+             'name': 'pg_sg2',
+             'acls': []}]
+        del_port_groups_list = ['pg_unknown_del']
 
         add_subnet_dhcp_options_list = [(self.subnets[2], self.networks[1]),
                                         (self.subnets[1], self.networks[0])]
@@ -873,22 +826,12 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                       del_snat_list,
                                       add_floating_ip_list,
                                       del_floating_ip_list,
-                                      add_address_set_list,
-                                      del_address_set_list,
-                                      update_address_set_list,
                                       add_subnet_dhcp_options_list,
                                       delete_dhcp_options_list,
                                       add_port_groups_list,
-                                      del_port_groups_list,
-                                      port_groups_supported)
+                                      del_port_groups_list)
 
-    def test_ovn_nb_sync_mode_repair_no_pgs(self):
-        self._test_ovn_nb_sync_mode_repair_helper(port_groups_supported=False)
-
-    def test_ovn_nb_sync_mode_repair_pgs(self):
-        self._test_ovn_nb_sync_mode_repair_helper(port_groups_supported=True)
-
-    def _test_ovn_nb_sync_mode_log_helper(self, port_groups_supported=True):
+    def test_ovn_nb_sync_mode_log(self):
         create_network_list = []
         create_port_list = []
         create_provnet_port_list = []
@@ -905,9 +848,6 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         del_snat_list = []
         add_floating_ip_list = []
         del_floating_ip_list = []
-        add_address_set_list = []
-        del_address_set_list = []
-        update_address_set_list = []
         add_subnet_dhcp_options_list = []
         delete_dhcp_options_list = []
         add_port_groups_list = []
@@ -934,20 +874,10 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                       del_snat_list,
                                       add_floating_ip_list,
                                       del_floating_ip_list,
-                                      add_address_set_list,
-                                      del_address_set_list,
-                                      update_address_set_list,
                                       add_subnet_dhcp_options_list,
                                       delete_dhcp_options_list,
                                       add_port_groups_list,
-                                      del_port_groups_list,
-                                      port_groups_supported)
-
-    def test_ovn_nb_sync_mode_log_pgs(self):
-        self._test_ovn_nb_sync_mode_log_helper(port_groups_supported=True)
-
-    def test_ovn_nb_sync_mode_log_no_pgs(self):
-        self._test_ovn_nb_sync_mode_log_helper(port_groups_supported=False)
+                                      del_port_groups_list)
 
 
 class TestOvnSbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
